@@ -23,39 +23,14 @@
 #include <config.h>
 #endif
 
-#include <string.h>
 #include <glib.h>
-#include <gdbus.h>
 #include <gatchat.h>
-#include <stdlib.h>
 
 #define OFONO_API_SUBJECT_TO_CHANGE
 #include <ofono/plugin.h>
-#include <ofono/log.h>
-#include <ofono/modem.h>
-#include "at.h"
+#include <ofono/types.h>
 
-void dump_response(const char *func, gboolean ok, GAtResult *result)
-{
-	GSList *l;
-
-	ofono_debug("%s got result: %d", func, ok);
-	ofono_debug("Final response: %s", result->final_or_pdu);
-
-	for (l = result->lines; l; l = l->next)
-		ofono_debug("Response line: %s", (char *) l->data);
-}
-
-void decode_at_error(struct ofono_error *error, const char *final)
-{
-	if (!strcmp(final, "OK")) {
-		error->type = OFONO_ERROR_TYPE_NO_ERROR;
-		error->error = 0;
-	} else {
-		error->type = OFONO_ERROR_TYPE_FAILURE;
-		error->error = 0;
-	}
-}
+#include "atmodem.h"
 
 static int atmodem_init(void)
 {
@@ -71,6 +46,7 @@ static int atmodem_init(void)
 	at_sms_init();
 	at_sim_init();
 	at_netreg_init();
+	at_cbs_init();
 
 	return 0;
 }
@@ -89,6 +65,7 @@ static void atmodem_exit(void)
 	at_netreg_exit();
 	at_devinfo_exit();
 	at_voicecall_exit();
+	at_cbs_exit();
 }
 
 OFONO_PLUGIN_DEFINE(atmodem, "AT modem driver", VERSION,
